##
# This file is part of WhatWeb and may be subject to
# redistribution and commercial restrictions. Please see the WhatWeb
# web site for more information on licensing and terms of use.
# https://www.morningstarsecurity.com/research/whatweb
#
Plugin.define "Deprecated-Plugin-Format" do
author "Andrew Horton"
description "Tests the deprecated plugin format for WhatWeb version < 0.5.0."

end
